@@ -30,8 +30,8 @@ from contextlib import contextmanager
 from squeak.core.elliptic import scalar_difference
 from squeak.core.elliptic import scalar_from_bytes
 from squeak.core.elliptic import scalar_to_bytes
-from squeak.core.signing import SqueakPrivateKey
-from squeak.core.signing import SqueakPublicKey
+from squeak.core.keys import SqueakPrivateKey
+from squeak.core.keys import SqueakPublicKey
 
 from proto import lnd_pb2
 from proto import squeak_admin_pb2
@@ -342,21 +342,6 @@ def get_sell_price(node_stub):
     return get_sell_price_response
 
 
-def set_twitter_bearer_token(node_stub, bearer_token):
-    node_stub.SetTwitterBearerToken(
-        squeak_admin_pb2.SetTwitterBearerTokenRequest(
-            bearer_token=bearer_token,
-        )
-    )
-
-
-def get_twitter_bearer_token(node_stub):
-    get_twitter_bearer_token_response = node_stub.GetTwitterBearerToken(
-        squeak_admin_pb2.GetTwitterBearerTokenRequest()
-    )
-    return get_twitter_bearer_token_response.bearer_token
-
-
 def get_external_address(node_stub):
     get_external_address_response = node_stub.GetExternalAddress(
         squeak_admin_pb2.GetExternalAddressRequest()
@@ -371,12 +356,14 @@ def get_default_peer_port(node_stub):
     return get_default_peer_port_response.port
 
 
-def make_squeak(node_stub, profile_id, squeak_content, reply_to_hash=None):
+def make_squeak(node_stub, profile_id, squeak_content, reply_to_hash=None, recipient_profile_id=None):
     make_squeak_response = node_stub.MakeSqueak(
         squeak_admin_pb2.MakeSqueakRequest(
             profile_id=profile_id,
             content=squeak_content,
             replyto=reply_to_hash,
+            has_recipient=(recipient_profile_id is not None),
+            recipient_profile_id=recipient_profile_id,
         )
     )
     return make_squeak_response.squeak_hash
